@@ -7,8 +7,9 @@ from filelock import FileLock
 from typing import List, Optional
 from dataclasses import dataclass
 from torch.utils.data.dataset import Dataset
-from transformers import PreTrainedTokenizer
 from ratsnlp.nlpbook.ner import NERTrainArguments
+
+from transformers import BertTokenizer
 from transformers.tokenization_utils_base import PaddingStrategy, TruncationStrategy
 
 
@@ -94,9 +95,11 @@ class NERCorpus:
 
 def _process_target_sentence(
         tokens: List[str],
+        origin_sentence: str,
         target_sentence: str,
         max_length: int,
         label_map: dict,
+        tokenizer: BertTokenizer,
         cls_token_at_end: Optional[bool] = False,
 ):
     """
@@ -106,12 +109,23 @@ def _process_target_sentence(
     label_sequence = ['O', 'B-PER', 'I-PER', 'O', 'O', 'B-PER', 'I-PER', 'I-PER', 'O',
                       'B-NOH', 'O', 'O', 'O', 'O', 'O', 'O', 'O']
     """
+    if "[UNK]" in tokens:
+        processed_tokens = []
+        basic_tokens = tokenizer.basic_tokenizer.tokenize(origin_sentence)
+        for basic_token in basic_tokens:
+            current_tokens = tokenizer.tokenize(basic_token)
+            if "[UNK]" in current_tokens:
+                # [UNK] 복원
+                processed_tokens.append(basic_token)
+            else:
+                processed_tokens.extend(current_tokens)
+    else:
+        processed_tokens = tokens
+
     prefix_sum_of_token_start_index, sum = [0], 0
-    for i, token in enumerate(tokens):
+    for i, token in enumerate(processed_tokens):
         if token.startswith("##"):
             sum += len(token) - 2
-        elif token in ["[UNK]"]:
-            sum += 1 # 대부분 ', "
         else:
             sum += len(token)
         prefix_sum_of_token_start_index.append(sum)
@@ -139,7 +153,7 @@ def _process_target_sentence(
     entity_index = 0
     is_entity_still_B = True
 
-    for tup in zip(tokens, prefix_sum_of_token_start_index):
+    for tup in zip(processed_tokens, prefix_sum_of_token_start_index):
         token, index = tup
 
         if entity_index < len(list_of_tuple_ner_start_end):
@@ -188,7 +202,7 @@ def _process_target_sentence(
 
 def _convert_examples_to_ner_features(
         examples: List[NERExample],
-        tokenizer: PreTrainedTokenizer,
+        tokenizer: BertTokenizer,
         args: NERTrainArguments,
         label_list: List[str],
         cls_token_at_end: Optional[bool] = False,
@@ -212,9 +226,11 @@ def _convert_examples_to_ner_features(
             )
             label_ids = _process_target_sentence(
                 tokens=tokens,
+                origin_sentence=example.text,
                 target_sentence=example.label,
                 max_length=args.max_seq_length,
                 label_map=label_map,
+                tokenizer=tokenizer,
                 cls_token_at_end=cls_token_at_end,
             )
             features.append(NERFeatures(**inputs, label_ids=label_ids))
@@ -235,7 +251,7 @@ class NERDataset(Dataset):
     def __init__(
             self,
             args: NERTrainArguments,
-            tokenizer: PreTrainedTokenizer,
+            tokenizer: BertTokenizer,
             corpus: NERCorpus,
             mode: Optional[str] = "train",
             convert_examples_to_features_fn=_convert_examples_to_ner_features,
